Re-exports
pub use rcgen;
Structs
- Certificate
- Represents a X.509 certificate with associated metadata
- Global
Certificate - GlobalCertificate implements SNI-based dynamic certificate selection
- TlsCertificate
- Represents a TLS certificate with its associated data
- TlsSetting
Params - Parameters for configuring TLS settings
Enums
Statics
Traits
Functions
- new_
certificate_ validity_ service - Creates a new background service for certificate validity checking
- new_
self_ signed_ certificate_ validity_ service - Creates a new service task for certificate validity checking.
- parse_
certificates - parse_
leaf_ chain_ certificates