pub struct TlsCertificate {
pub name: Option<String>,
pub chain_certificates: Option<Vec<X509>>,
pub certificate: Option<(X509, PKey<Private>)>,
pub domains: Vec<String>,
pub info: Option<Certificate>,
pub hash_key: String,
pub is_ca: bool,
pub buffer_days: u16,
}Expand description
Represents a TLS certificate with its associated data
Fields
name: Option<String>chain_certificates: Option<Vec<X509>>certificate: Option<(X509, PKey<Private>)>domains: Vec<String>info: Option<Certificate>hash_key: Stringis_ca: boolbuffer_days: u16Implementations
Sourceimpl TlsCertificate
impl TlsCertificate
Sourcepub fn get_self_signed_certificate(
&self,
server_name: &str,
) -> Result<Arc<SelfSignedCertificate>, Error>
pub fn get_self_signed_certificate( &self, server_name: &str, ) -> Result<Arc<SelfSignedCertificate>, Error>
Gets or creates a self-signed certificate for the given server name. If a cached certificate exists for the server name, returns that. Otherwise creates a new certificate signed by this CA.
Arguments
server_name- The server name to create the certificate for
Returns
An Arc containing the self-signed certificate